package com.ruoyi.system.mapper;

import com.ruoyi.system.domain.butler.ButlerSettings;

import java.util.List;

/**
 * 物业管家设置Mapper接口
 * 
 * @author boman
 * @date 2025-03-07
 */
public interface ButlerSettingsMapper 
{
    /**
     * 查询物业管家设置
     * 
     * @param settingsId 物业管家设置主键
     * @return 物业管家设置
     */
    public ButlerSettings selectButlerSettingsBySettingsId(Long settingsId);

    /**
     * 查询物业管家设置列表
     * 
     * @param butlerSettings 物业管家设置
     * @return 物业管家设置集合
     */
    public List<ButlerSettings> selectButlerSettingsList(ButlerSettings butlerSettings);

    /**
     * 新增物业管家设置
     * 
     * @param butlerSettings 物业管家设置
     * @return 结果
     */
    public int insertButlerSettings(ButlerSettings butlerSettings);

    /**
     * 修改物业管家设置
     * 
     * @param butlerSettings 物业管家设置
     * @return 结果
     */
    public int updateButlerSettings(ButlerSettings butlerSettings);

    /**
     * 删除物业管家设置
     * 
     * @param settingsId 物业管家设置主键
     * @return 结果
     */
    public int deleteButlerSettingsBySettingsId(Long settingsId);

    /**
     * 批量删除物业管家设置
     * 
     * @param settingsIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteButlerSettingsBySettingsIds(Long[] settingsIds);
}
